Class: EInvoiceAPI::Models::DocumentCreate::Item::Charge
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- EInvoiceAPI::Models::DocumentCreate::Item::Charge
- Defined in:
- lib/e_invoice_api/models/document_create.rb,
sig/e_invoice_api/models/document_create.rbs
Defined Under Namespace
Modules: Amount, BaseAmount, MultiplierFactor, ReasonCode, TaxCode, TaxRate
Instance Attribute Summary collapse
-
#amount ⇒ Float, ...
The charge amount, without VAT.
-
#base_amount ⇒ Float, ...
The base amount that may be used, in conjunction with the charge percentage, to calculate the charge amount.
-
#multiplier_factor ⇒ Float, ...
The percentage that may be used, in conjunction with the charge base amount, to calculate the charge amount.
-
#reason ⇒ String?
The reason for the charge.
-
#reason_code ⇒ Symbol, ...
Charge reason codes for invoice charges and fees.
-
#tax_code ⇒ Symbol, ...
Duty or tax or fee category codes (Subset of UNCL5305).
-
#tax_rate ⇒ Float, ...
The VAT rate, represented as percentage that applies to the charge.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount: nil, base_amount: nil, multiplier_factor: nil, reason: nil, reason_code: nil, tax_code: nil, tax_rate: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Charge for more details.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount: nil, base_amount: nil, multiplier_factor: nil, reason: nil, reason_code: nil, tax_code: nil, tax_rate: nil) ⇒ Object
Some parameter documentations has been truncated, see EInvoiceAPI::Models::DocumentCreate::Item::Charge for more details.
A charge is an additional fee for example for late payment, late delivery, etc.
|
|
# File 'lib/e_invoice_api/models/document_create.rb', line 1351
|
Instance Attribute Details
#amount ⇒ Float, ...
The charge amount, without VAT. Must be rounded to maximum 2 decimals
1299 |
# File 'lib/e_invoice_api/models/document_create.rb', line 1299 optional :amount, union: -> { EInvoiceAPI::DocumentCreate::Item::Charge::Amount }, nil?: true |
#base_amount ⇒ Float, ...
The base amount that may be used, in conjunction with the charge percentage, to calculate the charge amount. Must be rounded to maximum 2 decimals
1306 1307 1308 1309 1310 |
# File 'lib/e_invoice_api/models/document_create.rb', line 1306 optional :base_amount, union: -> { EInvoiceAPI::DocumentCreate::Item::Charge::BaseAmount }, nil?: true |
#multiplier_factor ⇒ Float, ...
The percentage that may be used, in conjunction with the charge base amount, to calculate the charge amount. To state 20%, use value 20
1317 1318 1319 |
# File 'lib/e_invoice_api/models/document_create.rb', line 1317 optional :multiplier_factor, union: -> { EInvoiceAPI::DocumentCreate::Item::Charge::MultiplierFactor }, nil?: true |
#reason ⇒ String?
The reason for the charge
1325 |
# File 'lib/e_invoice_api/models/document_create.rb', line 1325 optional :reason, String, nil?: true |
#reason_code ⇒ Symbol, ...
Charge reason codes for invoice charges and fees
1331 1332 1333 1334 1335 |
# File 'lib/e_invoice_api/models/document_create.rb', line 1331 optional :reason_code, enum: -> { EInvoiceAPI::DocumentCreate::Item::Charge::ReasonCode }, nil?: true |
#tax_code ⇒ Symbol, ...
Duty or tax or fee category codes (Subset of UNCL5305)
Agency: UN/CEFACT Version: D.16B Subset: OpenPEPPOL
1343 |
# File 'lib/e_invoice_api/models/document_create.rb', line 1343 optional :tax_code, enum: -> { EInvoiceAPI::DocumentCreate::Item::Charge::TaxCode }, nil?: true |
#tax_rate ⇒ Float, ...
The VAT rate, represented as percentage that applies to the charge
1349 |
# File 'lib/e_invoice_api/models/document_create.rb', line 1349 optional :tax_rate, union: -> { EInvoiceAPI::DocumentCreate::Item::Charge::TaxRate }, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/e_invoice_api/models/document_create.rb', line 1600
|
.variants ⇒ Array(Float, String)
|
|
# File 'lib/e_invoice_api/models/document_create.rb', line 1381
|
Instance Method Details
#to_hash ⇒ {
1175 |
# File 'sig/e_invoice_api/models/document_create.rbs', line 1175
def to_hash: -> {
|