Class: EInvoiceAPI::Resources::Outbox
- Inherits:
-
Object
- Object
- EInvoiceAPI::Resources::Outbox
- Defined in:
- lib/e_invoice_api/resources/outbox.rb
Instance Method Summary collapse
-
#initialize(client:) ⇒ Outbox
constructor
private
A new instance of Outbox.
- #list_draft_documents(page: nil, page_size: nil, search: nil, sort_by: nil, sort_order: nil, state: nil, type: nil, request_options: {}) ⇒ EInvoiceAPI::Internal::DocumentsNumberPage<EInvoiceAPI::Models::DocumentResponse> deprecated Deprecated.
-
#list_received_documents(date_from: nil, date_to: nil, page: nil, page_size: nil, receiver: nil, search: nil, sender: nil, sort_by: nil, sort_order: nil, type: nil, request_options: {}) ⇒ EInvoiceAPI::Internal::DocumentsNumberPage<EInvoiceAPI::Models::DocumentResponse>
Some parameter documentations has been truncated, see Models::OutboxListReceivedDocumentsParams for more details.
Constructor Details
#initialize(client:) ⇒ Outbox
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
Returns a new instance of Outbox.
94 95 96 |
# File 'lib/e_invoice_api/resources/outbox.rb', line 94 def initialize(client:) @client = client end |
Instance Method Details
#list_draft_documents(page: nil, page_size: nil, search: nil, sort_by: nil, sort_order: nil, state: nil, type: nil, request_options: {}) ⇒ EInvoiceAPI::Internal::DocumentsNumberPage<EInvoiceAPI::Models::DocumentResponse>
Deprecated.
Retrieve a paginated list of draft documents with filtering options including state and text search.
32 33 34 35 36 37 38 39 40 41 42 43 |
# File 'lib/e_invoice_api/resources/outbox.rb', line 32 def list_draft_documents(params = {}) parsed, = EInvoiceAPI::OutboxListDraftDocumentsParams.dump_request(params) query = EInvoiceAPI::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "api/outbox/drafts", query: query, page: EInvoiceAPI::Internal::DocumentsNumberPage, model: EInvoiceAPI::DocumentResponse, options: ) end |
#list_received_documents(date_from: nil, date_to: nil, page: nil, page_size: nil, receiver: nil, search: nil, sender: nil, sort_by: nil, sort_order: nil, type: nil, request_options: {}) ⇒ EInvoiceAPI::Internal::DocumentsNumberPage<EInvoiceAPI::Models::DocumentResponse>
Some parameter documentations has been truncated, see Models::OutboxListReceivedDocumentsParams for more details.
Retrieve a paginated list of sent documents with filtering options including state, type, sender, date range, and text search.
78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/e_invoice_api/resources/outbox.rb', line 78 def list_received_documents(params = {}) parsed, = EInvoiceAPI::OutboxListReceivedDocumentsParams.dump_request(params) query = EInvoiceAPI::Internal::Util.encode_query_params(parsed) @client.request( method: :get, path: "api/outbox/", query: query, page: EInvoiceAPI::Internal::DocumentsNumberPage, model: EInvoiceAPI::DocumentResponse, options: ) end |